/* edata.c
**
** data output functions
**
*/
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <errno.h>

#include "tools.h"
#include "vxerror.h"
#include "dbif.h"
#include "mrmacs.h"

int print_filter (DBIF_FILE db, char *domain)
{
    dbif_rec *rec;
    char *filter;
    filter = gconc (__FILE__, __LINE__, "::FILTER::@", domain, NULL);
    ifnull (rec = dbif_get (db, filter)) {
	vxerror (0, 0, "`%s' has no mail filter!\n", domain);
	return 1;
    }
    printf ("%s\n", rec->folder);
    dbif_free (rec);
    gfree (filter);
    return 0;
}

int print_folder (DBIF_FILE db, char *entry)
{
    dbif_rec *rec;
    int rt;
    ifnull (rec = dbif_resolve (db, entry, (char **) NULL, 1)) {
	vxerror (0, 0, "unknown %s entry `%s'!\n",
		       (isNULL(strchr (entry, '@')) ? "domain" : "user"),
		       entry);
	return 1;
    }
    rt = dbif_rectype (rec);
    if (rt == RT_LLINK) {
	char *fld = rec->folder;
	int mx = ((int) *fld++) + 1, ix;
	for (ix = 0; ix < mx; ++ix) {
	    printf ("%s\n", fld); fld += strlen (fld) + 1;
	}
    } else {
	printf ("%s\n", rec->folder);
    }
    dbif_free (rec);
    return 0;
}

int print_limits (DBIF_FILE db, char *entry)
{
    dbif_rec *rec;
    int nu, mu, rt;
    ifnull (rec = dbif_resolve (db, entry, (char **) NULL, 1)) {
	vxerror (0, 0, "unknown %s entry `%s'!\n",
		       (isNULL(strchr (entry, '@')) ? "domain" : "user"),
		       entry);
	return 1;
    }
    rt = dbif_rectype (rec);
    switch (rt) {
	case RT_DOMAIN:
	case RT_NSDOMAIN:
	    dbif_getlim (rec, &nu, &mu);
	    dbif_free (rec);
	    if (rt == RT_NSDOMAIN) { mu = 0; }
	    printf ((mu ? "%d\n" : "\n"), mu);
/*	    printf ((mu ? "%d %d\n" : "%d\n"), nu, mu);*/
	    return 0;
	case RT_USER:
	case RT_ADMIN:
	case RT_NSUSER:
	case RT_INVALID:
	    dbif_free (rec);
	    vxerror (0, 0, "Sorry - not implemented (yet)!\n");
	    return 1;
	default:
	    dbif_free (rec);
	    vxerror (0, 0, "invalid query!\n");
	    return 1;
    }
}

int print_profile (DBIF_FILE db, char *domain)
{
    fprintf (stderr, "Sorry - not implemented (yet)!\n");
    return 1;
}

int print_nusers (DBIF_FILE db, char *domain)
{
    dbif_rec *rec;
    int nu, mu, rt;
    ifnull (rec = dbif_resolve (db, domain, (char **) NULL, 1)) {
	vxerror (0, 0, "unknown %s entry `%s'!\n",
		       (isNULL(strchr (domain, '@')) ? "domain" : "user"),
		       domain);
	return 1;
    }
    rt = dbif_rectype (rec);
    if (rt == RT_DOMAIN || rt == RT_NSDOMAIN) {
	dbif_getlim (rec, &nu, &mu);
	dbif_free (rec);
	if (rt == RT_NSDOMAIN) { mu = 0; }
	printf ("%d\n", nu);
	return 0;
    }
    dbif_free (rec);
    vxerror (0, 0, "invalid query!\n");
    return 1;
}
